summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWang, Ce <ce.wang@intel.com>2015-02-10 08:33:34 +0800
committerXiang, Haihao <haihao.xiang@intel.com>2015-02-10 08:54:11 +0800
commit03023936763c9565bb3291f9d89d5c869bc4da9f (patch)
treeb0850bcba3cd1728c86a646c1cea2a1e3ca13df4
parentd9626b77f865ce7bdbc8c78988a86d3e4f55d67b (diff)
downloadlibva-03023936763c9565bb3291f9d89d5c869bc4da9f.tar.gz
Add support for 10b vp9 decode
Signed-off-by: Sun, Maggie <maggie.sun@intel.com>
-rw-r--r--va/va.h6
-rw-r--r--va/va_dec_vp9.h12
2 files changed, 13 insertions, 5 deletions
diff --git a/va/va.h b/va/va.h
index 5796579..eeb8e34 100644
--- a/va/va.h
+++ b/va/va.h
@@ -335,8 +335,10 @@ typedef enum
VAProfileH264StereoHigh = 16,
VAProfileHEVCMain = 17,
VAProfileHEVCMain10 = 18,
- VAProfileVP9Version0 = 19,
- VAProfileVP9Version0Still = 20
+ VAProfileVP9Profile0 = 19,
+ VAProfileVP9Profile1 = 20,
+ VAProfileVP9Profile2 = 21,
+ VAProfileVP9Profile3 = 22
} VAProfile;
/**
diff --git a/va/va_dec_vp9.h b/va/va_dec_vp9.h
index 30584ed..d943e52 100644
--- a/va/va_dec_vp9.h
+++ b/va/va_dec_vp9.h
@@ -181,10 +181,16 @@ typedef struct _VADecPictureParameterBufferVP9
uint8_t mb_segment_tree_probs[7];
uint8_t segment_pred_probs[3];
/** \brief VP9 version number
* value can be 0 or 1.
*/
- uint8_t version;
+ uint8_t profile;
+
+ /** \brief VP9 bit depth per sample
+ * same for both luma and chroma samples.
+ */
+ uint8_t bit_depth;
+
/**@}*/
} VADecPictureParameterBufferVP9;
@@ -181,10 +181,16 @@ typedef struct _VADecPictureParameterBufferVP9
uint8_t mb_segment_tree_probs[7];
uint8_t segment_pred_probs[3];
- /** \brief VP9 version number
- * value can be 0 or 1.
+ /** \brief VP9 Profile definition
+ * value range [0..3].
*/